# Replication of "null results" - Absence of evidence or evidence of absence?

This repository contains code and data related to

Pawel, S., Heyard, R., Micheloud, C., Held, L. (2023). Replication of "null
results" - Absence of evidence or evidence of absence?

## Reproducibility

Our results can be reproduced in two ways

### 1. Reproducing the results locally

Make sure that LaTeX (e.g., texlive-full on Ubuntu), R, and the R packages
indicated in the `./CRANpackages.txt` file are installed

```sh
## install packages from CRAN by running from a shell
R -e 'install.packages(read.delim("CRANpackages.txt", header = FALSE)[,1])'
```

Then run 

```
make local
```

this should produce `./rsabsence.pdf`

Although the analyses depend on only few dependencies, this approach may lead to
different results (or not even compile successfully) in the future if R or the
packages change. The R and R package versions which were used when the thesis
was successfully compiled the last time are visible in the following output

```r
sessionInfo()

#> R version 4.2.3 (2023-03-15)
#> Platform: x86_64-pc-linux-gnu (64-bit)
#> Running under: Ubuntu 20.04.6 LTS
#> 
#> Matrix products: default
#> BLAS:   /usr/lib/x86_64-linux-gnu/blas/libblas.so.3.9.0
#> LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.9.0
#> 
#> locale:
#>  [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
#>  [3] LC_TIME=de_CH.UTF-8        LC_COLLATE=en_US.UTF-8    
#>  [5] LC_MONETARY=de_CH.UTF-8    LC_MESSAGES=en_US.UTF-8   
#>  [7] LC_PAPER=de_CH.UTF-8       LC_NAME=C                 
#>  [9] LC_ADDRESS=C               LC_TELEPHONE=C            
#> [11] LC_MEASUREMENT=de_CH.UTF-8 LC_IDENTIFICATION=C       
#> 
#> attached base packages:
#> [1] stats     graphics  grDevices utils     datasets  methods   base     
#> 
#> other attached packages:
#> [1] ggrepel_0.9.2     reporttools_1.1.3 xtable_1.8-4      dplyr_1.0.10     
#> [5] ggplot2_3.4.0     knitr_1.41       
#> 
#> loaded via a namespace (and not attached):
#>  [1] Rcpp_1.0.9       magrittr_2.0.3   tidyselect_1.2.0 munsell_0.5.0   
#>  [5] colorspace_2.1-0 R6_2.5.1         rlang_1.0.6      fansi_1.0.3     
#>  [9] tools_4.2.3      grid_4.2.3       gtable_0.3.1     xfun_0.36       
#> [13] utf8_1.2.2       cli_3.6.0        DBI_1.1.3        withr_2.5.0     
#> [17] assertthat_0.2.1 tibble_3.1.8     lifecycle_1.0.3  vctrs_0.5.1     
#> [21] glue_1.6.2       compiler_4.2.3   pillar_1.8.1     generics_0.1.3  
#> [25] scales_1.2.1     pkgconfig_2.0.3 

cat(paste(Sys.time(), Sys.timezone(), "\n"))

#> 2023-03-24 09:56:25 Europe/Zurich 
```

### 2. Reproducing the results within a Docker container

Make sure that Docker with root rights is installed. Then run

```
make docker
```

This may take some time as TinyTeX needs to install several LaTeX packages (run
`make docker2` to compile only R code within the container but run LaTeX
locally). The Docker approach reruns the analyses in a Docker container which
encapsulates the computational environment (R and R package versions) that was
used in the original analysis. The only way this approach could become
non-reproducible is when the
[rocker/verse](https://hub.docker.com/r/rocker/verse/tags) base image becomes
unavailable and/or the Posit Public Package Manager (RStudio Package Manager,
RSPM) snapshot of CRAN becomes unavailable.
